==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/CloudWatchEvents/PutPartnerEvents.pm <==

package Paws::CloudWatchEvents::PutPartnerEvents;
  use Moose;
  has Entries => (is => 'ro', isa => 'ArrayRef[Paws::CloudWatchEvents::PutPartnerEventsRequestEntry]', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'PutPartnerEvents');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CloudWatchEvents::PutPartnerEventsResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchEvents::PutPartnerEvents - Arguments for method PutPartnerEvents on L<Paws::CloudWatchEvents>

=head1 DESCRIPTION

This class represents the parameters used for calling the method PutPartnerEvents on the
L<Amazon EventBridge|Paws::CloudWatchEvents> service. Use the attributes of this class
as arguments to method PutPartnerEvents.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to PutPartnerEvents.

=head1 SYNOPSIS

    my $events = Paws->service('CloudWatchEvents');
    my $PutPartnerEventsResponse = $events->PutPartnerEvents(
      Entries => [
        {
          Detail     => 'MyString',                    # OPTIONAL
          DetailType => 'MyString',                    # OPTIONAL
          Resources  => [ 'MyEventResource', ... ],    # OPTIONAL
          Source     => 'MyString',                    # OPTIONAL
          Time       => '1970-01-01T01:00:00',         # OPTIONAL
        },
        ...
      ],

    );

    # Results:
    my $Entries          = $PutPartnerEventsResponse->Entries;
    my $FailedEntryCount = $PutPartnerEventsResponse->FailedEntryCount;

    # Returns a L<Paws::CloudWatchEvents::PutPartnerEventsResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/events/PutPartnerEvents>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Entries => ArrayRef[L<Paws::CloudWatchEvents::PutPartnerEventsRequestEntry>]

The list of events to write to the event bus.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method PutPartnerEvents in L<Paws::CloudWatchEvents>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.45.tar.gz: Paws-0.45/lib/Paws/CloudWatchEvents/PutPartnerEvents.pm <==

package Paws::CloudWatchEvents::PutPartnerEvents;
  use Moose;
  has Entries => (is => 'ro', isa => 'ArrayRef[Paws::CloudWatchEvents::PutPartnerEventsRequestEntry]', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'PutPartnerEvents');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CloudWatchEvents::PutPartnerEventsResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchEvents::PutPartnerEvents - Arguments for method PutPartnerEvents on L<Paws::CloudWatchEvents>

=head1 DESCRIPTION

This class represents the parameters used for calling the method PutPartnerEvents on the
L<Amazon EventBridge|Paws::CloudWatchEvents> service. Use the attributes of this class
as arguments to method PutPartnerEvents.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to PutPartnerEvents.

=head1 SYNOPSIS

    my $events = Paws->service('CloudWatchEvents');
    my $PutPartnerEventsResponse = $events->PutPartnerEvents(
      Entries => [
        {
          Detail     => 'MyString',                 # OPTIONAL
          DetailType => 'MyString',                 # OPTIONAL
          Resources  => [ 'MyEventResource', ... ], # OPTIONAL
          Source     => 'MyEventSourceName',        # min: 1, max: 256; OPTIONAL
          Time       => '1970-01-01T01:00:00',      # OPTIONAL
        },
        ...
      ],

    );

    # Results:
    my $Entries          = $PutPartnerEventsResponse->Entries;
    my $FailedEntryCount = $PutPartnerEventsResponse->FailedEntryCount;

    # Returns a L<Paws::CloudWatchEvents::PutPartnerEventsResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/events/PutPartnerEvents>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Entries => ArrayRef[L<Paws::CloudWatchEvents::PutPartnerEventsRequestEntry>]

The list of events to write to the event bus.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method PutPartnerEvents in L<Paws::CloudWatchEvents>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
